
STATS_COORDINATOR_CUSTOMER_JOBS_STARTED_COUNT = "coordinator.customer.jobs.started"
STATS_COORDINATOR_CUSTOMER_JOBS_WAITING_COUNT = "coordinator.customer.jobs.waiting"
STATS_COORDINATOR_JOB_MISSING_WORKER_COUNT = "coordinator.job.worker.missing"
